pub enum WorldStateError {
InvalidStateRoot,
IncompleteDatabase,
ValueAtIncompleteKey,
DecoderError,
InvalidHash,
ProtectedKey,
}Expand description
WorldStateError enumerates the possible error of WorldState.
Variants
InvalidStateRoot
Attempted to create a trie with a state root not in the database.
IncompleteDatabase
Trie item not found in the database,
ValueAtIncompleteKey
A value was found in the trie with a nibble key that was not byte-aligned.
DecoderError
Corrupt Trie item.
InvalidHash
Encoded node contains invalid hash reference.
ProtectedKey
Attempted to convert protected WSKey to AppKey