pub struct PoolKey {
pub operator: PublicAddress,
pub power: u64,
}Expand description
PoolKey is a small description of a pool. It affects the order of its representing pool in the Index Heap which is the state format of next validator set.
Fields
operator: PublicAddresspower: u64Implementations